News — Pootle 2.5.1 documentation

# News

Pootle provides the ability to access useful information about your language and projects. These can be read on Pootle, or through your RSS reader.

Project administrators can write notices, and Pootle will also generate entries automatically for these events:

- New languages
- New projects
- New projects added to languages
- Project updated from version control
- Project updated to templates
- File committed to version control
- File uploaded to project
- Archive uploaded to project
- File reached 100%